// 风险类型
export function riskType(val) {
  const strs = [
    '默认',
    '人',
    '物',
    '管'
  ]
  return strs[val]
}

// 风险等级
export function riskLevel(val) {
  const strs = [
    '默认',
    '重大',
    '较大',
    '一般',
    '较小'
  ]
  return strs[val]
}

// 风险等级
export function riskPointStatus(val) {
  const strs = [
    '未知',
    '安全受控',
    '失控'
  ]
  return strs[val]
}

// 风险点等级
export function riskPointLevel(val) {
  const strs = [
    '默认',
    '重大',
    '较大',
    '一般',
    '较小'
  ]
  return strs[val]
}

export function taskPriority(i) {
  const strs = [
    '未知',
    '较低',
    '普通',
    '紧急',
    '非常紧急'
  ]
  return strs[i]
}

export function taskType(i) {
  const strs = [
    '未知',
    '常规',
    '审批任务',
    '巡检任务'
  ]
  return strs[i]
}

export function taskStatus(i) {
  const strs = [
    '待处理',
    '已完成'
  ]
  if (i === -1) {
    return '已撤消'
  } else {
    return strs[i]
  }
}

export function checkResult(i) {
  const strs = [
    '没执行',
    '通过',
    '没通过',
    '有隐患',
    '已完成'
  ]
  return strs[i]
}

export function dangerStatus(i) {
  if (i >= 0) {
    const strs = [
      '待提交',
      '待评审',
      '待整改',
      '待验收',
      '已整改'
    ]
    return strs[i]
  } else {
    return '已撤销'
  }
}

export function dangerLevel(i) {
  const strs = [
    '未知',
    '重大',
    '较大',
    '严重',
    '一般'
  ]
  return strs[i]
}

export function dangerSource(i) {
  const strs = [
    '自查',
    '内部反馈',
    '上级抽查',
    '政府执法'
  ]
  return strs[i]
}

export function rectifyCat(i) {
  const strs = [
    '自行整改',
    '外协整改'
  ]
  return strs[i]
}

export function wfInsStatus(i) {
  if (i >= 0) {
    const strs = [
      '未开始',
      '执行中',
      '已完成'
    ]
    return strs[i]
  } else {
    return '已撤销'
  }
}

export function wfTaskInsStatus(i) {
  const strs = [
    '未开始',
    '已完成'
  ]
  return strs[i]
}

export function dangerRectifyCat(i) {
  const strs = [
    '自行整改',
    '外协整改'
  ]
  return strs[i]
}

export function alertLevel(i) {
  const strs = [
    '未知',
    '1级',
    '2级',
    '3级',
    '4级',
    '5级',
    '6级'
  ]
  return strs[i]
}

export function alertStatus(i) {
  if (i >= 0) {
    const strs = [
      '活动',
      '已解除'
    ]
    return strs[i]
  } else {
    return '已撤销'
  }
}
export function warningLevel(val) {
  const enums = { 1: 'Ⅰ级', 2: 'Ⅱ级', 3: 'Ⅲ级', 4: 'Ⅳ级' }
  return enums[val]
}
export function warningStatus(i) {
  if (i >= 0) {
    const strs = [
      '待处理',
      '已处理'
    ]
    return strs[i]
  } else {
    return '已撤销'
  }
}